import { ShortcutProps } from '@slimsag/react-shortcuts';
import H from 'history';
import * as React from 'react';
import { ContributableMenu, Contributions } from 'sourcegraph/module/protocol';
import { ControllerProps } from '../client/controller';
import { ExtensionsProps } from '../context';
import { ConfigurationSubject, Settings } from '../settings';
import { ActionItemProps } from './actions/ActionItem';
interface Props<S extends ConfigurationSubject, C extends Settings> extends ControllerProps<S, C>, ExtensionsProps<S, C> {
    /** The menu whose commands to display. */
    menu: ContributableMenu;
    /** Called when the user has selected an item in the list. */
    onSelect?: () => void;
    location: H.Location;
}
interface State {
    /** The contributions, merged from all extensions, or undefined before the initial emission. */
    contributions?: Contributions;
    input: string;
    selectedIndex: number;
    /** Recently invoked actions, which should be sorted first in the list. */
    recentActions: string[] | null;
}
/** Displays a list of commands contributed by extensions for a specific menu. */
export declare class CommandList<S extends ConfigurationSubject, C extends Settings> extends React.PureComponent<Props<S, C>, State> {
    private static RECENT_ACTIONS_STORAGE_KEY;
    private static readRecentActions;
    private static writeRecentActions;
    state: State;
    private subscriptions;
    private selectedItem;
    private setSelectedItem;
    componentDidMount(): void;
    componentDidUpdate(_prevProps: Props<S, C>, prevState: State): void;
    componentWillUnmount(): void;
    render(): JSX.Element | null;
    private onInputChange;
    private onInputKeyDown;
    private onSubmit;
    private setSelectedIndex;
    private onActionRun;
}
export declare function filterAndRankItems(items: Pick<ActionItemProps, 'action'>[], query: string, recentActions: string[] | null): ActionItemProps[];
export declare class CommandListPopoverButton<S extends ConfigurationSubject, C extends Settings> extends React.PureComponent<Props<S, C> & {
    toggleVisibilityKeybinding?: Pick<ShortcutProps, 'held' | 'ordered'>[];
}, {
    hideOnChange?: any;
}> {
    state: {
        hideOnChange?: any;
    };
    render(): JSX.Element | null;
    private dismissPopover;
}
export {};
