import * as React from 'react';
import { Subject, Subscription } from 'rxjs';
import { distinctUntilChanged, map, switchMap } from 'rxjs/operators';
import { BrowserConsoleTracer, Trace } from 'sourcegraph/module/protocol/jsonrpc2/trace';
import { PopoverButton } from '../ui/generic/PopoverButton';
import { Toggle } from '../ui/generic/Toggle';
export class ExtensionStatus extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = { trace: localStorage.getItem(ExtensionStatus.TRACE_STORAGE_KEY) !== null };
        this.componentUpdates = new Subject();
        this.subscriptions = new Subscription();
        this.onToggleTrace = () => {
            this.setState(prevState => ({ trace: !prevState.trace }), () => {
                if (this.state.trace) {
                    localStorage.setItem(ExtensionStatus.TRACE_STORAGE_KEY, 'true');
                }
                else {
                    localStorage.removeItem(ExtensionStatus.TRACE_STORAGE_KEY);
                }
                // Update trace setting for all existing connections.
                if (this.state.extensions) {
                    for (const e of this.state.extensions) {
                        e.connection
                            .then(c => c.trace(this.state.trace ? Trace.Verbose : Trace.Off, new BrowserConsoleTracer(e.key.id)))
                            .catch(err => console.error(err));
                    }
                }
            });
        };
    }
    componentDidMount() {
        const extensionsController = this.componentUpdates.pipe(map(({ extensionsController }) => extensionsController), distinctUntilChanged());
        this.subscriptions.add(extensionsController
            .pipe(switchMap(extensionsController => extensionsController.clientEntries), map(extensions => ({ extensions })))
            .subscribe(stateUpdate => this.setState(stateUpdate), err => console.error(err)));
        this.componentUpdates.next(this.props);
    }
    componentDidUpdate() {
        this.componentUpdates.next(this.props);
    }
    componentWillUnmount() {
        this.subscriptions.unsubscribe();
    }
    render() {
        return (React.createElement("div", { className: "extension-status card border-0" },
            React.createElement("div", { className: "card-header" }, "Active extensions (DEBUG)"),
            this.state.extensions ? (this.state.extensions.length > 0 ? (React.createElement("div", { className: "list-group list-group-flush" }, this.state.extensions.map(({ key }, i) => (React.createElement("div", { key: i, className: "list-group-item py-2 d-flex align-items-center justify-content-between" },
                React.createElement(this.props.link, { id: key.id })))))) : (React.createElement("span", { className: "card-body" }, "No active extensions."))) : (React.createElement("span", { className: "card-body" },
                React.createElement(this.props.loaderIcon, { className: "icon-inline" }),
                " Loading extensions...")),
            React.createElement("div", { className: "card-body border-top d-flex justify-content-end align-items-center" },
                React.createElement("label", { htmlFor: "extension-status__trace", className: "mr-2 mb-0" },
                    "Log to devtools console",
                    ' '),
                React.createElement(Toggle, { id: "extension-status__trace", onToggle: this.onToggleTrace, value: this.state.trace, title: "Toggle extension trace logging to devtools console" }))));
    }
}
ExtensionStatus.TRACE_STORAGE_KEY = 'traceExtensions';
/** A button that toggles the visibility of the ExtensionStatus element in a popover. */
export class ExtensionStatusPopover extends React.PureComponent {
    render() {
        return (React.createElement(PopoverButton, { caretIcon: this.props.caretIcon, placement: "auto-end", hideOnChange: this.props.location, popoverElement: React.createElement(ExtensionStatus, Object.assign({}, this.props)) },
            React.createElement("span", { className: "text-muted" }, "Ext")));
    }
}
//# sourceMappingURL=ExtensionStatus.js.map