import H from 'history';
import * as React from 'react';
import { ActionContribution } from 'sourcegraph/module/protocol';
import { ControllerProps } from '../../client/controller';
import { ExtensionsProps } from '../../context';
import { ErrorLike } from '../../errors';
import { ConfigurationSubject, Settings } from '../../settings';
export interface ActionItemProps {
    /**
     * The action specified in the menu item's {@link module:sourcegraph.module/protocol.MenuItemContribution#action}
     * property.
     */
    action: ActionContribution;
    /**
     * The alternative action specified in the menu item's
     * {@link module:sourcegraph.module/protocol.MenuItemContribution#alt} property.
     */
    altAction?: ActionContribution;
    variant?: 'actionItem';
    className?: string;
    /** Called when the item's action is run (possibly deferred). */
    onRun?: (actionID: string) => void;
    /**
     * Whether to set the disabled attribute on the element when execution is started and not yet finished.
     */
    disabledDuringExecution?: boolean;
    /** Instead of showing the icon and/or title, show this element. */
    title?: React.ReactElement<any>;
}
interface Props<S extends ConfigurationSubject, C extends Settings> extends ActionItemProps, ControllerProps<S, C>, ExtensionsProps<S, C> {
    location: H.Location;
}
declare const LOADING: 'loading';
interface State {
    /** The executed action: undefined while loading, null when done or not started, or an error. */
    actionOrError: typeof LOADING | null | ErrorLike;
}
export declare class ActionItem<S extends ConfigurationSubject, C extends Settings> extends React.PureComponent<Props<S, C>, State> {
    state: State;
    private commandExecutions;
    private subscriptions;
    componentDidMount(): void;
    componentDidUpdate(prevProps: Props<S, C>, prevState: State): void;
    componentWillUnmount(): void;
    render(): JSX.Element | null;
    runAction: (e: React.MouseEvent<Element> | React.KeyboardEvent<Element>) => void;
}
export {};
