import * as React from 'react';
import { Subject, Subscription } from 'rxjs';
import { switchMap } from 'rxjs/operators';
import { ActionItem } from './ActionItem';
import { getContributedActionItems } from './contributions';
/** Displays the actions in a container, with a wrapper and/or empty element. */
export class ActionsContainer extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.scopeChanges = new Subject();
        this.subscriptions = new Subscription();
        this.defaultRenderItems = (items) => (React.createElement(React.Fragment, null, items.map((item, i) => (React.createElement(ActionItem, Object.assign({ key: i }, item, { extensionsController: this.props.extensionsController, extensions: this.props.extensions, location: this.props.location }))))));
    }
    componentDidMount() {
        this.subscriptions.add(this.scopeChanges
            .pipe(switchMap(scope => this.props.extensionsController.registries.contribution.getContributions(scope)))
            .subscribe(contributions => this.setState({ contributions })));
        this.scopeChanges.next(this.props.scope);
    }
    componentDidUpdate(prevProps) {
        if (prevProps.scope !== this.props.scope) {
            this.scopeChanges.next(this.props.scope);
        }
    }
    componentWillUnmount() {
        this.subscriptions.unsubscribe();
    }
    render() {
        if (!this.state.contributions) {
            return null; // loading
        }
        const items = getContributedActionItems(this.state.contributions, this.props.menu);
        if (this.props.empty !== undefined && items.length === 0) {
            return this.props.empty;
        }
        const render = this.props.render || this.defaultRenderItems;
        return render(items);
    }
}
//# sourceMappingURL=ActionsContainer.js.map