import * as React from 'react';
import { Subject, Subscription } from 'rxjs';
import { switchMap } from 'rxjs/operators';
import { ActionItem } from './ActionItem';
import { getContributedActionItems } from './contributions';
/**
 * Renders the actions as a fragment of <li class="nav-item"> elements, for use in a Bootstrap <ul
 * class="nav"> or <ul class="navbar-nav">.
 */
export class ActionsNavItems extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.scopeChanges = new Subject();
        this.subscriptions = new Subscription();
    }
    componentDidMount() {
        this.subscriptions.add(this.scopeChanges
            .pipe(switchMap(scope => this.props.extensionsController.registries.contribution.getContributions(scope)))
            .subscribe(contributions => this.setState({ contributions })));
        this.scopeChanges.next(this.props.scope);
    }
    componentDidUpdate(prevProps) {
        if (prevProps.scope !== this.props.scope) {
            this.scopeChanges.next(this.props.scope);
        }
    }
    componentWillUnmount() {
        this.subscriptions.unsubscribe();
    }
    render() {
        if (!this.state.contributions) {
            return null; // loading
        }
        return (React.createElement(React.Fragment, null, getContributedActionItems(this.state.contributions, this.props.menu).map((item, i) => (React.createElement("li", { key: i, className: this.props.listClass || 'nav-item' },
            React.createElement(ActionItem, Object.assign({ key: i }, item, { variant: "actionItem", extensionsController: this.props.extensionsController, extensions: this.props.extensions, className: this.props.actionItemClass, location: this.props.location })))))));
    }
}
//# sourceMappingURL=ActionsNavItems.js.map