import marked from 'marked';
import * as React from 'react';
import { MessageType } from 'sourcegraph/module/protocol';
import { isErrorLike } from '../../errors';
/**
 * A notification message displayed in a {@link module:./Notifications.Notifications} component.
 */
export class NotificationItem extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.onDismiss = () => this.props.onDismiss(this.props.notification);
    }
    render() {
        const markdownHTML = marked(isErrorLike(this.props.notification.message)
            ? this.props.notification.message.message
            : this.props.notification.message, { gfm: true, breaks: true, sanitize: true });
        return (React.createElement("div", { className: `sourcegraph-notification-item alert alert-${alertClass(this.props.notification.type)} p-0 ${this.props.className || ''}` },
            React.createElement("div", { className: "sourcegraph-notification-item__content py-2 pl-2 pr-0", dangerouslySetInnerHTML: { __html: markdownHTML } }),
            React.createElement("button", { type: "button", className: "sourcegraph-notification-item__close p-2", onClick: this.onDismiss, "aria-label": "Close" },
                React.createElement("span", { "aria-hidden": "true" }, "\u00D7"))));
    }
}
/**
 * @return The Bootstrap class that corresponds to {@link type}.
 */
function alertClass(type) {
    switch (type) {
        case MessageType.Error:
            return 'danger';
        case MessageType.Warning:
            return 'warning';
        default:
            return 'info';
    }
}
//# sourceMappingURL=NotificationItem.js.map