import * as React from 'react';
import { Subscription } from 'rxjs';
import { NotificationItem } from './NotificationItem';
/**
 * A notifications center that displays global, non-modal messages.
 */
export class Notifications extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {
            notifications: [],
        };
        this.subscriptions = new Subscription();
        this.onDismiss = (notification) => {
            this.setState(prevState => ({ notifications: prevState.notifications.filter(n => n !== notification) }));
        };
    }
    componentDidMount() {
        this.subscriptions.add(this.props.extensionsController.notifications.subscribe(notification => {
            this.setState(prevState => ({
                notifications: [notification, ...prevState.notifications.slice(0, Notifications.MAX_RETAIN - 1)],
            }));
        }));
    }
    componentWillUnmount() {
        this.subscriptions.unsubscribe();
    }
    render() {
        return (React.createElement("div", { className: "sourcegraph-notifications" }, this.state.notifications.slice(0, Notifications.MAX_RETAIN).map((notification, i) => (React.createElement(NotificationItem, { key: i, notification: notification, onDismiss: this.onDismiss, className: "sourcegraph-notifications__notification rounded-0 m-2" })))));
    }
}
/**
 * The maximum number of notifications at a time. Older notifications are truncated when the length exceeds
 * this number.
 */
Notifications.MAX_RETAIN = 7;
//# sourceMappingURL=Notifications.js.map