import { Unsubscribable } from 'rxjs';
import { Controller } from 'sourcegraph/module/client/controller';
import { Extension } from 'sourcegraph/module/client/extension';
import { ActionContributionClientCommandUpdateConfiguration, ConfigurationUpdateParams } from 'sourcegraph/module/protocol';
import { Context } from '../context';
import { ConfigurationCascade, ConfigurationSubject, Settings } from '../settings';
/**
 * Registers the builtin client commands that are required for Sourcegraph extensions. See
 * {@link module:sourcegraph.module/protocol/contribution.ActionContribution#command} for
 * documentation.
 */
export declare function registerBuiltinClientCommands<S extends ConfigurationSubject, C extends Settings>(context: Pick<Context<S, C>, 'configurationCascade' | 'updateExtensionSettings' | 'queryGraphQL' | 'queryLSP'>, controller: Controller<Extension, ConfigurationCascade<S, C>>): Unsubscribable;
/**
 * Constructs the URL that will result in the panel being opened to the specified view. Other parameters in the URL
 * hash are preserved.
 *
 * @param viewID The ID of the view to open in the panel.
 * @param urlHash The current URL hash (beginning with '#' if non-empty).
 */
export declare function urlForOpenPanel(viewID: string, urlHash: string): string;
/**
 * Applies an edit to the configuration settings of the highest-precedence subject.
 */
export declare function updateConfiguration<S extends ConfigurationSubject, C extends Settings>(context: Pick<Context<S, C>, 'configurationCascade' | 'updateExtensionSettings'>, params: ConfigurationUpdateParams): Promise<void>;
/**
 * Converts the arguments for the `updateConfiguration` client command (as documented in
 * {@link ActionContributionClientCommandUpdateConfiguration#commandArguments})
 * to {@link ConfigurationUpdateParams}.
 */
export declare function convertUpdateConfigurationCommandArgs(args: ActionContributionClientCommandUpdateConfiguration['commandArguments']): ConfigurationUpdateParams;
