export const isErrorLike = (val) => !!val && typeof val === 'object' && (!!val.stack || ('message' in val || 'code' in val)) && !('__typename' in val);
/**
 * Ensures a value is a proper Error, copying all properties if needed.
 */
export const asError = (err) => {
    if (err instanceof Error) {
        return err;
    }
    if (typeof err === 'object' && err !== null) {
        return Object.assign(new Error(err.message), err);
    }
    return new Error(err);
};
/**
 * Creates an AggregateError from multiple ErrorLikes.
 *
 * @param errors errors or ErrorLikes to aggregate
 */
export const createAggregateError = (errors = []) => Object.assign(new Error(errors.map(e => e.message).join('\n')), {
    name: 'AggregateError',
    errors: errors.map(asError),
});
//# sourceMappingURL=errors.js.map