import { Shortcut } from '@slimsag/react-shortcuts';
import * as React from 'react';
import Popover from 'reactstrap/lib/Popover';
import { LinkOrSpan } from './LinkOrSpan';
/**
 * A button that toggles the visibility of a popover.
 */
export class PopoverButton extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = { open: false };
        this.rootRef = null;
        this.onClickLink = (e) => {
            this.setState({ open: false });
        };
        this.setRootRef = (e) => (this.rootRef = e);
        this.toggleVisibility = () => this.setState(prevState => ({ open: !prevState.open }));
    }
    componentWillReceiveProps(props) {
        if (props.hideOnChange !== this.props.hideOnChange) {
            this.setState({ open: false });
        }
    }
    render() {
        const isOpen = this.state.open || this.props.open;
        const popoverAnchor = this.rootRef && (React.createElement(Popover, { placement: this.props.placement || 'auto-start', isOpen: isOpen, toggle: this.toggleVisibility, target: this.rootRef, className: `popover-button2__popover ${this.props.popoverClassName || ''}` },
            isOpen && React.createElement(Shortcut, { ordered: ['Escape'], onMatch: this.toggleVisibility, ignoreInput: true }),
            this.props.popoverElement));
        return (React.createElement("div", { className: `popover-button2 ${isOpen ? 'popover-button2--open' : ''} ${this.props.className || ''} ${this.props.link ? 'popover-button2__container' : 'popover-button2__btn popover-button2__anchor'}`, ref: this.setRootRef },
            React.createElement(LinkOrSpan, { className: this.props.link
                    ? 'popover-button2__btn popover-button2__btn--link'
                    : 'popover-button2__container', to: this.props.link, onClick: this.props.link ? this.onClickLink : this.toggleVisibility },
                this.props.children,
                ' ',
                !this.props.link && React.createElement(this.props.caretIcon, { className: "icon-inline popover-button2__icon" })),
            this.props.link ? (React.createElement("div", { className: "popover-button2__anchor" },
                React.createElement(this.props.caretIcon, { className: "icon-inline popover-button2__icon popover-button2__icon--outside", onClick: this.toggleVisibility }),
                popoverAnchor)) : (popoverAnchor),
            this.props.toggleVisibilityKeybinding &&
                !isOpen &&
                this.props.toggleVisibilityKeybinding.map((keybinding, i) => (React.createElement(Shortcut, Object.assign({ key: i }, keybinding, { onMatch: this.toggleVisibility }))))));
    }
}
//# sourceMappingURL=PopoverButton.js.map